#
# These are the definitions for doc2lt and doctext nroff output
#
# Doc2lt single line entry?
key        %n%p<CODE>%1</CODE>
definition %n.B %1%n
#
# Possible alternates (see /usr/lib/tmac/tmac.an)
# .HP len - hanging indent
# .IP name len - indented paragraph (typical use .IP \fIvalues\fP 1in)
# .TP len - hanging label (sets amount)
# .TP (no len) do label (? does indentation stick to subsequent paragraphs?)
# .RS - increase relative indent
# .RE - decreate relative indent
# .IX arg arg .... - index entry
# .SS arg - subsection heading
# .SM - small
# .RI - Roman Italic ?
# .RB - Roman bold ?
# .IR, .IB, .BR, .BI similar
# .SB - small boldface
# .LP - paragraph
# .PP - same as .LP
# .PD len - paragraph distance ?
s_synopsis %n.SH SYNOPSIS%n.nf%n
e_synopsis %n.fi%n
em_dash    \-  
eop
bop
bof
eof
em	   %n.B 
s_arg      %n.PD 0%n.TP%n.B 
s_defn     %n- 
e_defn     %n.PD 1%n
e_arg      %n
s_arg_list
s_arg_inlist      %n.PD 0%n.TP%n.B 
s_defn_inlist     %n- 
e_defn_inlist     %n.PD 1%n
e_arg_inlist      %n
e_arg_list
s_doctext_verbatim %n.br%n
e_doctext_verbatim %n
# To really do large regions of text in a different font, we need
# to change every new line (!?)
s_caption  %n.RS
e_caption  %n.RE
picture
mantitle   %n.TH %1 %2 "%3" " " "%4"%n.SH NAME%n%1 
mantitlemany   %n.TH %1 %2 "%3" " " "%4"%n.SH NAME%n%1 
location   %n.SH LOCATION%n%1%n
anchor